@@ -145,6 +145,11 @@ int main(int argc, char* argv[])
     /// メモリリークの監視を開始 ///
     CHECKML_BEGIN();
 
+#if defined(HAVE_GC_H) || defined(HAVE_GC_GC_H)
+    /// GC 開始 ///
+    GC_init();
+#endif
+
     /// 乱数初期化 ///
     srandom(1000);
 
