@@ -12,10 +12,6 @@
 
 #include <limits.h>
 
-#if defined(__DARWIN__)
-#include <sys/syslimits.h>
-#endif
-
 //////////////////////////////////////////////////////////////////////
 // ?g???q?????Ԃ?
 //////////////////////////////////////////////////////////////////////
