@@ -314,7 +314,7 @@ void sVar_delete(sVar* self);
 sVar* sVar_load(int fd);
 void sVar_save(sVar* self, int fd);
 
-sBlock* sBlock_new(sStatments* statments, vector_obj* args);
+sBlock* sBlock_new(sStatments* statments, vector_obj* args, int count);
 sBlock* sBlock_new2(sBlock* block);
 void sBlock_delete(sBlock* self);
 void sBlock_save(sBlock* self, int fd);
@@ -360,13 +360,11 @@ typedef struct
 } sCommand;
 
 #ifdef MDEBUG 
-sCommand* sCommand_new(const char* file, int line, const char* function);
-#define COMMAND_NEW() sCommand_new(__FILE__, __LINE__, __FUNCTION__)
 void sCommand_view(sCommand* self);
-#else
+#endif
+
 sCommand* sCommand_new();
 #define COMMAND_NEW() sCommand_new()
-#endif
 
 void sCommand_save(sCommand* self, int fd);
 sCommand* sCommand_load(int fd);
@@ -397,36 +395,21 @@ typedef struct
 } sStatment;
 
 #ifdef MDEBUG
-
-sStatment* sStatment_new(const char* file, int line, const char* function);
-#define STATMENT_NEW() sStatment_new(__FILE__, __LINE__, __FUNCTION__)
 void sStatment_view(sStatment* self);
-
-#else
+#endif
 
 sStatment* sStatment_new();
 #define STATMENT_NEW() sStatment_new()
 
-#endif
-
 sStatment* sStatment_new2(sStatment* statment);
 
 void sStatment_delete(sStatment* self);
 void sStatment_save(sStatment* self, int fd);
 sStatment* sStatment_load(int fd);
 
-#ifdef MDEBUG
-sStatments* sStatments_new(const char* file, int line, const char* function);
-
-#define STATMENTS_NEW() sStatments_new(__FILE__, __LINE__, __FUNCTION__)
-#else
-
 sStatments* sStatments_new();
-
 #define STATMENTS_NEW() sStatments_new()
 
-#endif
-
 void sStatments_view(sStatments* self);
 
 void sStatments_save(sStatments* self, int fd);
