@@ -1739,27 +1739,6 @@ sIf* sIf_load(int fd)
 /////////////////////////////////////////////////////////
 // コマンド ls -al
 /////////////////////////////////////////////////////////
-#ifdef MDEBUG 
-
-sCommand* sCommand_new(const char* file, int line, const char* function)
-{
-    sCommand* self = CheckMemLeak_Malloc(sizeof(sCommand), file, line, "COMMAND_NEW");
-
-    self->mKind = kCommand;
-    self->mArgTmps = VECTOR_NEW(50);
-    self->mArgs = VECTOR_NEW(50);
-
-    self->mRedirects = VECTOR_NEW(10);
-
-    self->mExtra = NULL;
-
-    return self;
-}
-
-#define COMMAND_NEW() sCommand_new(__FILE__, __LINE__, __FUNCTION__)
-
-#else
-
 sCommand* sCommand_new()
 {
     sCommand* self = MALLOC(sizeof(sCommand));
@@ -1777,8 +1756,6 @@ sCommand* sCommand_new()
 
 #define COMMAND_NEW() sCommand_new()
 
-#endif
-
 sCommand* sCommand_new2(sCommand* command)
 {
     sCommand* self = MALLOC(sizeof(sCommand));
@@ -2039,31 +2016,6 @@ void sCommand_delete(sCommand* self)
 /////////////////////////////////////////////////////////
 // 文 ls -al | grep aaa
 /////////////////////////////////////////////////////////
-#ifdef MDEBUG
-
-sStatment* sStatment_new(const char* file, int line, const char* function)
-{
-    sStatment* self = CheckMemLeak_Malloc(sizeof(sStatment), file, line, "STATMENT_NEW");
-
-    self->mCommands = VECTOR_NEW(30);
-    self->mTerminated = kTNormal;
-    self->mFName = STRING_NEW("");
-    self->mLine = 0;
-    self->mTitle = STRING_NEW("");
-    self->mNotEvaled = NULL;
-    self->mBackground = FALSE;
-    self->mRCodeReverse = FALSE;
-
-    self->mGlobalPipeIn = FALSE;
-    self->mGlobalPipeOut = FALSE;
-
-    return self;
-}
-
-#define STATMENT_NEW() sStatment_new(__FILE__, __LINE__, __FUNCTION__)
-
-#else
-
 sStatment* sStatment_new()
 {
     sStatment* self = MALLOC(sizeof(sStatment));
@@ -2085,8 +2037,6 @@ sStatment* sStatment_new()
 
 #define STATMENT_NEW() sStatment_new()
 
-#endif
-
 sStatment* sStatment_new2(sStatment* statment)
 {
     sStatment* self = MALLOC(sizeof(sStatment));
@@ -2387,21 +2337,6 @@ sStatment* sStatment_load(int fd)
 /////////////////////////////////////////////////////////
 // 複文 ls -al | grep aaa; pwd; cd aaa
 /////////////////////////////////////////////////////////
-#ifdef MDEBUG
-sStatments* sStatments_new(const char* file, int line, const char* function)
-{
-    sStatments* self = CheckMemLeak_Malloc(sizeof(sStatments)
-                            , file, line, "STATMENTSLIST_NEW");
-
-    self->mStatments = VECTOR_NEW(30);
-
-    return self;
-}
-
-#define STATMENTSLIST_NEW() sStatments_new(__FILE__, __LINE__, __FUNCTION__)
-
-#else
-
 sStatments* sStatments_new()
 {
     sStatments* self = MALLOC(sizeof(sStatments));
@@ -2413,8 +2348,6 @@ sStatments* sStatments_new()
 
 #define STATMENTSLIST_NEW() sStatments_new()
 
-#endif
-
 sStatments* sStatments_new2(sStatments* statments)
 {
     sStatments* self = MALLOC(sizeof(sStatments));
@@ -2935,7 +2868,7 @@ void saphire_init(enum eAppType app_type, BOOL job_control, enum eRuntimeScript
 
     gReadBuffers = HASH_NEW(100);
 
-    setenv("SAPHIRE_VERSION", "1.4.0", 1);
+    setenv("SAPHIRE_VERSION", "1.4.1", 1);
     setenv("SAPHIRE_PROMPT", "> ", 1);
     setenv("SAPHIRE_DOCDIR", DOCDIR, 1);
     char* home = getenv("HOME");
@@ -3951,12 +3884,13 @@ void saphire_make_var_completion_list()
     (void)vector_sort(gSaphireVarCompletions, name_sort);
 }
 
-sBlock* sBlock_new(sStatments* statments, vector_obj* args)
+sBlock* sBlock_new(sStatments* statments, vector_obj* args, int count)
 {
     sBlock* self = MALLOC(sizeof(sBlock));
 
     self->mStatments = statments;
     self->mArgs = args;
+    self->mCount = count;
 
     return self;
 }
@@ -3971,6 +3905,7 @@ sBlock* sBlock_new2(sBlock* block)
     for(i=0; i<vector_size(block->mArgs); i++) {
         vector_add(self->mArgs, STRING_NEW(string_c_str(vector_item(block->mArgs, i))));
     }
+    self->mCount = 0;
 
     return self;
 }
